# Example Notebook

Check this [sample notebook](https://git.sophia.mines-paristech.fr/oie/libinsitu/-/blob/encoding-demo/encoding-demo.ipynb?ref_type=heads) 
that demonstrates how to encode CSV or Excel data to NetCDF with *libinsitu* and read it back.

You can run this notebook online with *binder* :
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/git/https%3A%2F%2Fgit.sophia.mines-paristech.fr%2Foie%2Flibinsitu.git/encoding-demo?labpath=encoding-demo.ipynb)
